//
//  AdvShowView.m
//  广告页
//
//  Created by AG_TigerNong on 17/3/24.
//  Copyright © 2017年 农大浒. All rights reserved.
//

#import "AdvShowView.h"
#import <UIImageView+WebCache.h>

@interface AdvShowView ()<UIScrollViewDelegate>
//图片路径数组
@property (nonatomic, strong) NSArray *imageUrls;

//滚动视图
@property (nonatomic, strong) UIScrollView *scrollView;

//页码
@property (nonatomic, strong) UIPageControl *pageVC;

//广告时间
@property (nonatomic, assign) NSInteger interval;

//关闭广告按钮
@property (nonatomic, weak) UIButton * button;

@property (nonatomic, copy) pushToAdvBlock blcok;

@property (nonatomic, strong) NSTimer *timer;

@end

@implementation AdvShowView

#pragma mark - 对外方法

- (void)show{
    [self startTimer];
    UIWindow *window = [UIApplication sharedApplication].keyWindow;
    [window addSubview:self];
}

- (void)clcikAdvIndex:(pushToAdvBlock)block{
    if (block) {
        self.blcok = block;
    }
}

- (id)initWithFrame:(CGRect)frame withImageUrls:(NSArray *)imageUrls withInterval:(NSInteger)interval{
    if (self = [super initWithFrame:frame]) {
        //设置滚动视图
        self.scrollView = [[UIScrollView alloc] initWithFrame:frame];
        [self addSubview:self.scrollView];
        self.scrollView.showsVerticalScrollIndicator = NO;
        self.scrollView.showsHorizontalScrollIndicator = NO;
        self.scrollView.pagingEnabled = YES;
        self.scrollView.contentSize = CGSizeMake(imageUrls.count * frame.size.width, 0);
        self.scrollView.bounces = NO;
        self.scrollView.delegate = self;
        
        //设置滚动视图里面的图片
        self.imageUrls = imageUrls;
        
        for (NSInteger i = 0; i < imageUrls.count; i ++) {
            CGRect rect = CGRectMake(i * self.scrollView.bounds.size.width, 0, self.scrollView.bounds.size.width, self.scrollView.bounds.size.height);
            UIImageView *imageView = [[UIImageView alloc] initWithFrame:rect];
            
            [self.scrollView addSubview:imageView];
            
            imageView.tag = i;
            imageView.userInteractionEnabled = YES;
            
            [imageView sd_setImageWithURL:[NSURL URLWithString:imageUrls[i]] placeholderImage:[UIImage imageNamed:@""] options:SDWebImageRefreshCached];
            
            UITapGestureRecognizer *tap = [[UITapGestureRecognizer alloc] initWithTarget:self action:@selector(pushToAdv:)];
            [imageView addGestureRecognizer:tap];
            
        }
        
        self.pageVC = [[UIPageControl alloc] initWithFrame:CGRectMake(0, frame.size.height - 30, frame.size.width, 30)];
        self.pageVC.currentPageIndicatorTintColor = [UIColor redColor];
        self.pageVC.pageIndicatorTintColor = [UIColor grayColor];
        self.pageVC.numberOfPages = imageUrls.count;
        [self addSubview:self.pageVC];
        
        //设置跳过按钮
        UIButton * button = [[UIButton alloc] initWithFrame:CGRectMake(self.scrollView.bounds.size.width - 110, 40, 90, 30)];
        [self addSubview:button];
        self.button = button;
        
        button.layer.cornerRadius = 3;
        button.layer.masksToBounds = YES;
        button.backgroundColor = [[UIColor blackColor] colorWithAlphaComponent:0.5];
        button.titleLabel.font = [UIFont systemFontOfSize:13];
        
        [button setTitle:[NSString stringWithFormat:@"跳过广告%ld>",interval] forState:UIControlStateNormal];
        
        self.interval = interval;
        
        [button addTarget:self action:@selector(closeAdv) forControlEvents:UIControlEventTouchUpInside];
        
    }
    return self;
}


#pragma mark - 对内方法

- (NSTimer *)timer{
    if (!_timer) {
        _timer = [NSTimer scheduledTimerWithTimeInterval:1.0 target:self selector:@selector(timeCount) userInfo:nil repeats:YES];
        
        [[NSRunLoop mainRunLoop] addTimer:_timer forMode:NSRunLoopCommonModes];
    }
    return _timer;
}
- (void)closeAdv{

    [self dismiss];
    
    [self.timer invalidate];
    self.timer = nil;
}

/*点击广告图片，进入*/
- (void)pushToAdv:(UITapGestureRecognizer *)t{
    UIImageView *imageView = (UIImageView *)t.view;
    
    if (self.blcok) {
        self.blcok(imageView.tag);
    }
    
    [self dismiss];
}


- (void)dismiss{
    
    [UIImageView animateWithDuration:3.0 animations:^{
        [self.scrollView removeFromSuperview];
        [self.button removeFromSuperview];
        
    } completion:^(BOOL finished) {
        
        [self removeFromSuperview];
    }];
}

- (void)startTimer{
    
    [self timer];
}

- (void)timeCount{
    
    self.interval --;
    
    if (self.interval == 0 || self.interval < 0) {
        
        [self.timer invalidate];
        self.timer = nil;
        
        [self dismiss];
    }else{
        [self.button setTitle:[NSString stringWithFormat:@"跳过广告%ld>",self.interval] forState:UIControlStateNormal];
    }
}

#pragma mark- UIScrollViewDelegate
- (void)scrollViewDidScroll:(UIScrollView *)scrollView{
    
    self.pageVC.currentPage = round(scrollView.contentOffset.x / self.scrollView.bounds.size.width);
    
}




@end
